@@ -3,7 +3,7 @@
 
 # noipy.dnsupdater
 # Copyright (c) 2013 Pablo O Vieira (povieira)
-# See README.md and LICENSE.md for details.
+# See README.rst and epl-v10.html for details.
 
 from __future__ import print_function
 
@@ -68,25 +68,28 @@ class DnsUpdaterPlugin(object):
         #request.get_method = lambda: 'GET'
         request.add_header('Authorization', 'Basic %s' % self.auth.base64key.decode('utf-8'))
 
-        response = urllib2.urlopen(request)
+        try:
+            response = urllib2.urlopen(request)
+            self.last_status_code = response.read().decode('utf-8')
+        except urllib2.HTTPError as e:
+            self.last_status_code = str(e.code)
 
-        self.last_status_code = response.read().decode('utf-8')
-
-    def print_status_message(self):
+    @property
+    def status_message(self):
         """(str) -> NoneType
         
-        Print friendly response from API based on response code.   
+        Return friendly response from API based on response code.   
         """
 
         msg = '' 
-        if 'good' in self.last_status_code or 'nochg' in self.last_status_code:
+        if self.last_status_code in ['badauth', 'nochg', '401', '403']:
+            msg = 'ERROR: Invalid username or password (%s).' % self.last_status_code
+        elif 'good' in self.last_status_code or 'nochg' in self.last_status_code:
             ip = re.search(r'(\d{1,3}\.?){4}', self.last_status_code).group()
             if 'good' in self.last_status_code:
                 msg = 'SUCCESS: DNS hostname IP (%s) successfully updated.' % ip
             else:
                 msg = 'SUCCESS: IP address (%s) is up to date, nothing was changed. Additional "nochg" updates may be considered abusive.' % ip
-        elif self.last_status_code == 'badauth':
-            msg = 'ERROR: Invalid username or password.'
         elif self.last_status_code == '!donator':
             msg = 'ERROR: Update request include a feature that is not available to informed user.'
         elif self.last_status_code == 'notfqdn':
@@ -106,7 +109,7 @@ class DnsUpdaterPlugin(object):
         else:
             msg = 'WARNING: Ooops! Something went wrong !!!'
 
-        print(msg)
+        return msg
 
     def __str__(self):
         return '%s(host=%s)' % (type(self).__name__, self.hostname)
