@@ -3,7 +3,7 @@
 
 # noipy.noipy
 # Copyright (c) 2013 Pablo O Vieira (povieira)
-# See README.md and LICENSE.md for details.
+# See README.rst and epl-v10.html for details.
 
 from __future__ import print_function
 
@@ -87,7 +87,7 @@ def main():
     print('Updating hostname "%s" with IP address %s ...' % (args.hostname, ip_address))
 
     updater.update_dns(ip_address)
-    updater.print_status_message()
+    print(updater.status_message)
 
 if __name__ == '__main__':
     main()
